/**
 * @description  单页管理接口
 * @license Apache License Version 2.0
 * @Copyright (c) 2022-Now 少林寺驻北固山办事处大神父王喇嘛
 * @remarks
 * SimpleAdmin 基于 Apache License Version 2.0 协议发布，可用于商业项目，但必须遵守以下补充条款:
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改SimpleAdmin源码头部的版权声明。
 * 3.分发源码时候，请注明软件出处 https://gitee.com/dotnetmoyu/SimpleAdmin
 * 4.基于本软件的作品，只能使用 SimpleAdmin 作为后台服务，除外情况不可商用且不允许二次分发或开源。
 * 5.请不得将本软件应用于危害国家安全、荣誉和利益的行为，不能以任何形式用于非法为目的的行为不要删除和修改作者声明。
 * 6.任何基于本软件而产生的一切法律纠纷和责任，均于我司无关
 * @see https://gitee.com/dotnetmoyu/SimpleAdmin
 */
import { moduleRequest } from "@/api/request";
import { ReqId, ResPage, ReqPersonId, SysDepartment } from "@/api/interface";
const http = moduleRequest("/business/department/");

/**
 * @Description: 单页管理
 * @Author: wwp
 * @Date: 2023-12-15 15:34:54
 */
const userManageDepartmentApi = {
  // 获取院系分页列表
  page(params: SysDepartment.Page) {
    return http.get("getPageList", params);
  },
  /** 新增院系 */
  add(params: SysDepartment.DepartmentInfo) {
    return http.post("add", params);
  },
  /** 修改院系 */
  update(params: SysDepartment.DepartmentInfo) {
    return http.put("update", params);
  },
  /** 删除院系 */
  delete(params: ReqId) {
    return http.post("delete", params);
  },
  // 院系详情
  detail(params: ReqId) {
    return http.get("getInfo", params);
  },
  /**院系列表（不分页）*/
  list(params: any) {
    return http.get("getNoPageList", params);
  }
};

const departmentButtonCode = {
  /** 新增院系 */
  add: "userManageDepartmentAdd",
  /** 删除院系 */
  edit: "userManageDepartmentEdit",
  /** 删除院系 */
  delete: "userManageDepartmentDelete"
};

export { userManageDepartmentApi, departmentButtonCode };
